/* Help text for OperServ */

static const char *os_help[] = {
"OperServ commands:",
"    \2MODE\2       Change a channel's modes",
"    \2KICK\2       Kick a user from a channel",
"    \2AKILL\2      Manipulate the AKILL list",
"    \2GLOBAL\2     Send a message to all users",
"    \2STATS\2      Show status of Services and network",
"",
"Commands available to Services admins only:",
"    \2SET\2        Set various global Services options",
"    \2UPDATE\2     Force the Services databases to be",
"                       updated on disk immediately",
"    \2QUIT\2       Terminate the Services program",
"    \2JUPE\2       \"Jupiter\" a server",
"    \2RAW\2        Send a raw string to the IRC server",
"",
"Commands available to the Services super-user only:",
"    \2ADMIN\2      Modify the Services admin list",
"",
"\2Notice:\2 All commands sent to OperServ are logged!",
NULL
};

/*************************************************************************/

static const char *mode_help[] = {
"Syntax: MODE \37channel\37 \37modes\37",
"",
"Allows IRCops to set channel modes for any channel.",
"Parameters are the same as for the standard /MODE",
"command.",
NULL
};

/*************************************************************************/

static const char *kick_help[] = {
"Syntax: KICK \37channel\37 \37user\37 \37reason\37",
" ",
"Allows IRCops to kick a user from any channel.",
"Parameters are the same as for the standard /KICK",
"command.  The kick message will have the nickname of the",
"IRCop sending the KICK command prepended; for example:",
"",
"*** SpamMan has been kicked off channel #my_channel by OperServ (Alcan (Flood))",
NULL
};

/*************************************************************************/

static const char *admin_help[] = {
"Syntax: ADMIN ADD \37nick\37",
"        ADMIN DEL \37nick\37",
"        ADMIN LIST",
"",
"Allows the Services super-user to add or remove nicknames",
"to or from the Services admin list.  A user whose nickname",
"is on the Services admin list and who has identified to",
"NickServ will be able to access Services admin commands.",
NULL
};

/*************************************************************************/

static const char *akill_help[] = {
"Syntax: AKILL ADD [+\37expiry\37] \37mask\37 \37reason\37",
"        AKILL DEL \37mask\37",
"        AKILL LIST [\37mask\37]",
"        AKILL VIEW [\37mask\37]",
"",
"Allows IRCops to manipulate the AKILL list.  If a user",
"matching an AKILL mask attempts to connect, Services will",
"issue a KILL for that user and, on supported server types,",
"will instruct all servers to add a ban (K-line) for the",
"mask which the user matched.",
"",
"AKILL ADD adds the given user@host mask to the AKILL",
"list for the given reason (which \2must\2 be given).",
"AKILL DEL removes the given mask from the AKILL list if it",
"is present.  AKILL LIST shows all current AKILLs; if the",
"optional mask is given, the list is limited to those",
"AKILLs matching the mask.  AKILL VIEW is a more verbose",
"version of AKILL LIST, and will show who added an AKILL,",
"the date it was added, and when it expires, as well as the",
"user@host mask and reason.",
"",
"Optionally, an expiry time can be given with the AKILL ADD",
"command.  The expiry time precedes the user@host mask, and",
"is specified as an integer followed by one of \37d\37 (days),",
"\37h\37 (hours), or \37m\37 (minutes).  Combinations (such as \371h30m\37)",
"are not permitted.  If a unit specifier is not included,",
"the default is days (so \37+30\37 by itself means 30 days).  To",
"add an AKILL which does not expire, use \37+0\37.  If the",
"usermask to be added starts with a \37+\37, an expiry time must",
"be given, even if it is the same as the default.  The",
"current AKILL default expiry time can be found with the",
"\2STATS AKILL\2 command.",
"",
"The \37reason\37 is intended for use by IRC operators only, and",
"will not be displayed to users in KILL messages.",
NULL
};

/*************************************************************************/

static const char *stats_help[] = {
"Syntax: \2STATS [AKILL | ALL]\2",
"",
"Without any option, shows the current number of users and",
"IRCops online (excluding Services), the highest number of",
"users online since Services was started, and the length of",
"time Services has been running.",
"",
"With the \2AKILL\2 option, displays the current size of the",
"AKILL list and the current default expiry time.",
"",
"The \2ALL\2 option is available only to Services admins, and",
"displays information on Services' memory usage.  Using this",
"option can freeze Services for a short period of time on",
"large networks, so don't overuse it!",
NULL
};

/*************************************************************************/

static const char *set_help[] = {
"Syntax: \2SET \37option\37 \37setting\37\2",
"",
"Sets various global Services options.  Option names",
"currently defined are:",
"    \2READONLY\2   Set read-only or read-write mode",
"",
"Limited to \2Services Admin\2.",
NULL
};

/*************************************************************************/

static const char *set_readonly_help[] = {
"Syntax: \2SET READONLY {ON|OFF}\2",
"",
"Sets read-only mode on or off.  In read-only mode, normal",
"users will not be allowed to modify any Services data,",
"including channel and nickname access lists, etc.  IRCops",
"will be able to modify Services' AKILL list and drop or",
"forbid nicknames and channels, but any such changes will",
"not be saved unless read-only mode is deactivated before",
"Services is terminated.",
"",
"This option is equivalent to the command-line option",
"\2-readonly\2.",
};

/*************************************************************************/

static const char *update_help[] = {
"Syntax: \2UPDATE\2",
"",
"Forces Services to update the channel, nick, and memo",
"databases as soon as you send the command.  Useful",
"before shutdowns.",
"Limited to \2Services Admin\2.",
NULL
};

/************************************************************************/

static const char *quit_help[] = {
"Syntax: \2QUIT\2",
"",
"Causes Services to do an immediate shutdown.  It is",
"a good idea to update the databases using the",
"\2UPDATE\2 command beforehand.",
"\2NOTE:\2 This command is NOT to be toyed with--using",
"it without good reason can disrupt network operations,",
"especially if a person with access to restart Services",
"is not around.",
"Limited to \2Services Admin\2.",
NULL
};

/************************************************************************/

static const char *shutdown_help[] = {
"Syntax: \2SHUTDOWN\2",
"",
"Tells Services to shut down, but save databases.  It is",
"a \"clean\" alternative to \2QUIT\2.",
"\2NOTE:\2 This command is NOT to be toyed with--using",
"it without good reason can disrupt network operations,",
"especially if a person with access to restart Services",
"is not around.",
"Limited to \2Services Admin\2.",
NULL
}; 

/************************************************************************/

static const char *restart_help[] = {
"Syntax: \2RESTART\2",
"",
"Tells Services to save databases and restart (i.e. exit",
"and immediately re-run the executable).",
"Limited to \2Services Admin\2.",
NULL
};

/************************************************************************/

static const char *jupe_help[] = {
"Syntax: \2JUPE \37server\37\2",
"",
"Tells Services to jupiter a server -- that is, to create",
"a fake \"server\" connected to Services which prevents",
"the real server of that name from connecting.  The jupe",
"may be removed using a standard \2SQUIT\2.",
"To be used \2only\2 in a situation where a server is",
"disrupting the network and must be juped.",
"Limited to \2Services Admin\2.",
NULL
};

/*************************************************************************/

static const char *raw_help[] = {
"Syntax: \2RAW \37text\37\2",
"",
"Sends a string of text directly to the server to which",
"Services is connected.  This command has a very limited",
"range of uses, and can wreak havoc on a network if used",
"improperly.  \2DO NOT USE THIS COMMAND\2 unless you are",
"absolutely certain you know what you are doing!",
"Limited to \2Services Admin\2.",
NULL
};

/*************************************************************************/
